WyRand

Struct WyRand 

pub struct WyRand { /* private fields */ }
A Pseudorandom Number generator, powered by the wyrand algorithm. This generator is based on the final v4.2 reference implementation.

Implementations

Source

impl WyRand

pub const fn new(state: u64) -> WyRand

Creates a new WyRand instance with the provided seed. Be sure to obtain the seed value from a good entropy source, either from hardware, OS source, or from a suitable crate, like getrandom.

pub fn rand(&mut self) -> u64

Generates a random u64 value and advances the PRNG state.

pub const fn gen_u64(seed: u64) -> (u64, u64)

Const WyRand generator. Generates and returns a random u64 value first and then the advanced state second.

use wyrand::WyRand;

let seed = 123;

let (random_value, new_state) = WyRand::gen_u64(seed);

assert_ne!(random_value, 0);
// The original seed now no longer matches the new state.
assert_ne!(new_state, seed);